Hotfix
[mailer.git] / ref.php
diff --git a/ref.php b/ref.php
index cff2ace8d92b92855c1f2b55757d2f8e208dc72c..f3308e2ee0a96f5bcf0f2c11657bd1a29de9ce66 100644 (file)
--- a/ref.php
+++ b/ref.php
@@ -6,20 +6,18 @@
  * -------------------------------------------------------------------- *
  * File              : ref.php                                          *
  * -------------------------------------------------------------------- *
* Short description : Redirection for the referal link                 *
  * -------------------------------------------------------------------- *
* Kurzbeschreibung  : Weiterleitungsscript fuer die Referal-Links      *
  * -------------------------------------------------------------------- *
  * $Revision::                                                        $ *
  * $Date::                                                            $ *
  * $Tag:: 0.2.1-FINAL                                                 $ *
  * $Author::                                                          $ *
- * Needs to be in all Files and every File needs "svn propset           *
- * svn:keywords Date Revision" (autoprobset!) at least!!!!!!            *
  * -------------------------------------------------------------------- *
  * Copyright (c) 2003 - 2009 by Roland Haeder                           *
- * Copyright (c) 2009, 2010 by Mailer Developer Team                    *
- * For more information visit: http://www.mxchange.org                  *
+ * Copyright (c) 2009 - 2011 by Mailer Developer Team                   *
+ * For more information visit: http://mxchange.org                      *
  *                                                                      *
  * This program is free software; you can redistribute it and/or modify *
  * it under the terms of the GNU General Public License as published by *
@@ -40,6 +38,9 @@
 // Load security stuff here
 require('inc/libs/security_functions.php');
 
+// Init start time
+$GLOBALS['startTime'] = microtime(true);
+
 // Set module
 $GLOBALS['module'] = 'ref';
 $GLOBALS['output_mode'] = -1;
@@ -51,54 +52,28 @@ require('inc/config-global.php');
 setContentType('text/html');
 
 // No refid by default
-$URL = 'modules.php?module=index';
-
-if (determineReferalId() > 0) {
-       // Test if nickname or numeric id
-       if (isExtensionActive('nickname')) {
-               // Nickname in URL, so load the id
-               fetchUserData(determineReferalId(), 'nickname');
-
-               // Do we have an entry?
-               if (isUserDataValid()) {
-                       // Load userid
-                       $GLOBALS['refid'] = getUserData('userid');
-               } else {
-                       // So do we have a userid?
-                       fetchUserData(determineReferalId());
-
-                       // Do we have an entry?
-                       if (!isUserDataValid()) {
-                               // No entry, so no referal id
-                               $GLOBALS['refid'] = getConfig('def_refid');
-                       } // END - if
-               }
-       } // END - if
-
-       // Update session
-       setSession('refid', determineReferalId());
+$url = 'modules.php?module=index';
 
-       // Is the refid valid?
-       if (determineReferalId() > 0) {
-               // Update ref counter
-               SQL_QUERY_ESC("UPDATE `{?_MYSQL_PREFIX?}_user_data` SET `ref_clicks`=`ref_clicks`+1 WHERE `userid`=%s LIMIT 1",
-                       array(determineReferalId()), __FILE__, __LINE__);
+// Check for determined referral id
+if ((isExtensionActive('user')) && (isReferralIdValid()) && (isValidUserId(determineReferralId()))) {
+       // Update ref counter
+       SQL_QUERY_ESC("UPDATE `{?_MYSQL_PREFIX?}_user_data` SET `ref_clicks`=`ref_clicks`+1 WHERE `userid`=%s LIMIT 1",
+               array(convertZeroToNull(determineReferralId())), __FILE__, __LINE__);
 
-               // Base URL for redirection
-               switch (getConfig('refid_target')) {
-                       case 'register':
-                               $URL = 'modules.php?module=index&what=register';
-                               break;
+       // Base URL for redirection
+       switch (getConfig('refid_target')) {
+               case 'register':
+                       $url = 'modules.php?module=index&what=register';
+                       break;
 
-                       case 'index':
-                               $URL = 'modules.php?module=index';
-                               break;
-               } // END - switch
-       } // END - if
+               case 'index':
+                       $url = 'modules.php?module=index';
+                       break;
+       } // END - switch
 } // END - if
 
 // Load the URL
-redirectToUrl($URL);
+redirectToUrl($url);
 
 // [EOF]
 ?>
@@ -6,20 +6,18 @@
  * File              : ref.php                                          *
  * -------------------------------------------------------------------- *
- * Short description : Redirection for the referal link                 *
+ * Short description : Redirection for the referral link                *
  * -------------------------------------------------------------------- *
@@ -6,20 +6,18 @@
  * -------------------------------------------------------------------- *
- * Kurzbeschreibung  : Weiterleitungsscript fuer die Referal-Links      *
+ * Kurzbeschreibung  : Weiterleitungsscript fuer die Referral-Links     *
  * -------------------------------------------------------------------- *
  * $Revision::                                                        $ *